pub enum Error {
Io(Error),
Value(String),
}Expand description
An error that occurred during serialization.
Variants
Io(Error)
An error from the underlying writer.
Value(String)
A value cannot be represented in CBOR.
Contains a description of the problem. Without the alloc feature
only a static description can be carried, so the messages that serde
composes at runtime are reduced to a generic one.