Module value

Module value 

A dynamic CBOR value.

Structs

Integer
An abstract integer value.

Enums

Error
An error when serializing to or deserializing from a Value.
KeyOrder
The map key ordering used by deterministic encoding.
Value
A representation of any CBOR item that can be inspected and manipulated dynamically.